@@ -14,23 +14,23 @@
 # limitations under the License.
 
 import abc
-import typing
+from typing import TypeVar, Any
 
-
-tquestenv = typing.TypeVar("QuESTEnv")
-tqureg = typing.TypeVar("Qureg")
+tquestenv = TypeVar("QuESTEnv")
+tqureg = TypeVar("Qureg")
+paulihamil = TypeVar("PauliHamil")
 
 
 class _PYQUEST(abc.ABC):
 
-    def __init__(self, interactive: bool = True):
+    def __init__(self, interactive: bool = True) -> None:
         self._interactive = True
 
-    def __call__(self, *args, **kwargs):
+    def __call__(self, *args, **kwargs) -> Any:
         return self.call_interactive(*args, **kwargs)
 
     @abc.abstractmethod
-    def call_interactive(self, *args, **kwargs):
+    def call_interactive(self, *args, **kwargs) -> Any:
         pass
 
     @property
